/***************************************************************************
                          connectorboolinpropertywidget.cpp  -  description
                             -------------------
    begin                : Sat Jan 27 2001
    copyright            : (C) 2001 by Rasmus Diekenbrock
    email                : ksimus@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// C-Includes

// QT-Includes

// KDE-Includes

// Project-Includes
#include "connectorboolinpropertywidget.h"

// Forward declaration



ConnectorBoolInPropertyWidget::ConnectorBoolInPropertyWidget(ConnectorBase * connector, QWidget *parent, const char *name)
	:	ConnectorPropertyWidget(connector, parent, name)
{
}

ConnectorBoolInPropertyWidget::~ConnectorBoolInPropertyWidget()
{
}

